#
# spec file for package docbook_5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define schemaversions 5.0 5.1
%define lastschemaversion 5.1
#
Name:           docbook_5
Version:        5.1.0
Release:        lp152.4.3
Summary:        DocBook Schemas (DTD, RELAX NG, W3C Schema) for Version 5.x
License:        SUSE-Oasis-Specification-Notice
Group:          Productivity/Publishing/DocBook
Url:            http://www.oasis-open.org/docbook/
# XML Catalog Entry
Source1:        %{name}.xml
Source2:        %{name}-README.SUSE
# DocBook Sources
Source3:        docbook-5.0-docs.tar.bz2
Source4:        docbook-5.1-docs.tar.bz2
Source5:        Makefile
# DB 5.0
Source500:      docbook-5.0.tar.bz2
# DB 5.1
Source510:      docbook-5.1.tar.bz2
#
# PATCH-FIX-OPENSUSE docbook_5-nvdl.patch change path to schema files
Patch501:       %{name}-nvdl.patch

#
BuildRequires:  fdupes
BuildRequires:  sgml-skel
Requires:       sgml-skel >= 0.7
Requires(post): sgml-skel >= 0.7
Requires(postun): sgml-skel >= 0.7
BuildArch:      noarch

%description
DocBook is a schema. It is particularly well-suited to books and papers
about computer hardware and software (though it is not limited to these
applications at all).

The version is a complete rewrite of DocBook in RELAX NG.
The intent of this rewrite is to produce a schema that is true to the
spirit of DocBook while simultaneously removing inconsistencies that
have arisen as a natural consequence of DocBook's long, slow evolution.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The documentation for the DocBook 5.x specification (%{schemaversions})

%define xml_dir                %{_datadir}/xml
%define xml_docbook_dir        %{xml_dir}/docbook
%define xml_schema_dir         %{xml_dir}/docbook/schema
%define xml_docbook_dtd_dir    %{xml_schema_dir}/dtd
%define xml_docbook_rng_dir    %{xml_schema_dir}/rng
%define xml_docbook_sch_dir    %{xml_schema_dir}/sch
%define xml_docbook_xsd_dir    %{xml_schema_dir}/xsd
%define xml_docbook_nvdl_dir   %{xml_schema_dir}/nvdl
%define xml_docbook_custom_dir %{xml_docbook_dir}/custom
%define xml_docbook_style_dir  %{xml_docbook_dir}/stylesheet
%define xml_config_dir         %{_localstatedir}/lib/xml
%define xml_sysconf_dir        %{_sysconfdir}/xml

%prep
%setup -q -n %{name} -c -T
# Copy catalog, README, and Makefile
cp -p %{SOURCE1} %{SOURCE2} %{SOURCE5} .

# Unpack the sources:
tar -xf %{SOURCE500}
tar -xf %{SOURCE510}
# Unpack the documentation:
tar -xf %{SOURCE3}
tar -xf %{SOURCE4}

chmod -R a+rX,g-w,o-w .
find . -type f | xargs chmod a-x

# Patching
%patch501

%build
# Nothing to build

%install
make DESTDIR=%{buildroot}

# cleanup
%fdupes %{buildroot}

%post
update-xml-catalog

%postun
update-xml-catalog

%files
%config %{xml_sysconf_dir}/catalog.d/docbook_5.xml
%doc *README*
#
%dir %{xml_docbook_dir}/schema
%dir %{xml_docbook_dtd_dir}
%dir %{xml_docbook_rng_dir}
%dir %{xml_docbook_sch_dir}
%dir %{xml_docbook_xsd_dir}
%dir %{xml_docbook_nvdl_dir}
%dir %{xml_docbook_style_dir}
# 5.0
%{xml_docbook_dtd_dir}/5.0
%{xml_docbook_rng_dir}/5.0
%{xml_docbook_sch_dir}/5.0
%{xml_docbook_xsd_dir}/5.0
%{xml_docbook_nvdl_dir}/5.0
# 5.1
%{xml_docbook_rng_dir}/%{lastschemaversion}
%{xml_docbook_sch_dir}/%{lastschemaversion}
%{xml_docbook_nvdl_dir}/%{lastschemaversion}
# Upgrade stylesheet
%{xml_docbook_style_dir}/upgrade
#
%{_bindir}/db4-entities.pl

%files doc
%doc docbook*spec-cd-01.{pdf,html,xml}
%doc docbook*-os.{pdf,html,xml}

%changelog
* Fri Dec  8 2017 dimstar@opensuse.org
- Fix fdupes macro invocation: the fdupes macro knows no -q
  parameter.
* Sun Nov 12 2017 thomas.schraitle@suse.com
- Correct Makefile:
  - Add more pattern rules
  - Use more builtin make functions
  - Create links in nvdl directory to docbook.{rng,sch}
  - Add missing assembly.rn{c,g} and dbits.rn{c,g} for Schematron
- Correct spec file:
  - Add docbook_5-nvdl.patch to change path to DocBook RNG/SCH files
  - Apply spec-cleaner
* Wed Oct 11 2017 thomas.schraitle@suse.com
- New version 5.1
  - no DTD and XSD schemas for version 5.1 anymore!
- Changes in spec file:
  - used spec-cleaner
  - removed obsolete stuff
  - install files through Makefile
  - install NVDL files under /usr/share/xml/docbook/schema/nvdl
    instead as "documentation"
* Fri Jun 17 2016 fvogt@suse.com
- Split documentation into -doc subpackage
- Use newer sgml-spec
* Tue May 12 2015 toms@opensuse.org
- Changed DocBook catalog URIs to 5.1 instead of 5.1CR3
* Thu Feb 19 2015 toms@opensuse.org
- Fixed subtle XML catalog bug (bsc#918565)
- Added DocBook 5.1CR3
- Spec file changes:
  . Make post and postun sections work
  . Lots of entries in XML catalogs need to be generated, so it's
    easier to use for loops
* Mon Mar 18 2013 cfarrell@suse.com
- license update: SUSE-Oasis-Specification-Notice
  See any of the files in the docs/ subdirectory (section on notices and ip
  towards the end)
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Tue Jun  5 2012 ke@suse.de
- Reduce Requires (iso_ent and xmlcharent).
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug  3 2009 aj@suse.de
- Only remove file from catalog if it disappeared.
- Do not use release numbers, they're not needed anymore.
- Cleanup some rpmlint warnings: Non-executable-in-bin, duplicate
  requires, do not remove buildroot.
* Mon Feb 11 2008 toms@suse.de
- Release of version 5.0 (Committee Draft)
  There are no user-visible changes in 5.0 (Public Review Draft 1).
  This version of DocBook V5.0 will become the official Committee
  Specification version of DocBook V5.0 as soon as the
  Technical Committee balloting process is finished.
- Added DocBook Specification in PDF, HTML and XML
* Thu May 24 2007 toms@suse.de
- Updated to release 5.0CR4:
  * Fixed RFE 1708032: Pattern naming inconsistency; changed
    db.href.attribute to db.href.attributes.
  * Fixed RFE 1700154: Added sortas to <termdef>.
  * Fixed RFE 1686919: Added an NVDL rules file.
  * Fixed RFE 1705596: Aded db.programming.inlines (<classname>,
    <exceptionname>, <function>, <initializer>, <interfacename>,
    <methodname>, <modifier>, <ooclass>, <ooexception>, <oointerface>,
    <parameter>, <returnvalue>, <type>, and <varname>) to the
    content model of <code>.
  * Fixed RFE 1689228: Fixed typo in Schematron assertion.
* Fri Mar 23 2007 toms@suse.de
- Updated to release 5.0CR3:
  * RFE 1679775: Changed semantics of <termdef>. A <firstterm> is now
    required (instead of a <glossterm> as in previous releases). This
    allows the definition of one term to refer to another.
  * RFE 1682917: Added pgwide attribute to <example>.
  * RFE 1644553: Added label attribute to CALS and HTML tables.
  * RFE 1588693: Added an <acknowledgements> element, peer to
    <dedication>, replacing <ackno> which had only been available at the
    end of <article>.
  * After several months of consideration and experimentation, we decided
    to allow <info> in HTML tables.
  * RFE 1673820: Adopted "http://docbook.org/xlink/role/olink" as an XLink
    role (that is, the xlink:role attribute) value to identify OLinks
    expressed using XLink attributes.
* Wed Mar 14 2007 toms@suse.de
- Updated to release 5.0CR2:
  * Fixed RFE 1630203: Allow empty glossary.
  * Fixed RFE 1627845: Allow optional caption on CALS table and informaltable.
  * Related to RFE 1627845: Allow inlines in HTML table caption.
  * Fixed RFE 1589139 (and RFE 1621178): Allow title and titleabbrev on qandaentry.
  * Fixed RFE 1675932: Restore localname, prefix and namespace as class attribute values on tag.
  * Fixed RFE 1669465: Schematron rules should refer to @xml:id, not @id.
* Mon Feb 19 2007 toms@suse.de
- First release of 5.0CR1
